@@ -1,4 +1,4 @@
-InspectDistances=function(DataOrDistances,method= "euclidean",sampleSize = 10000,...){
+InspectDistances=function(DataOrDistances,method= "euclidean",sampleSize = 50000,...){
   # InspectDistance(DataOrDistances,method)
   # visualizes the distances between objects in the data matrix 
   # using the method specified by distance, which can be any of the following character strings
@@ -11,6 +11,8 @@ InspectDistances=function(DataOrDistances,method= "euclidean",sampleSize = 10000
   # method          method specified by distance string: 
   #                 'euclidean','sqEuclidean','mahalanobis','cityblock=manhatten','cosine','chebychev'=max(abs(x-y)),'jaccard','minkowski','manhattan','binary', 'canberra'=sum abs(x-y)/sum(abs(x)-abs(y)), 'maximum', 'braycur'=sum abs(x -y)/abs(x+y)
   #author: MT 06/16
+  #1.Editor: MT 06/18
+  requireNamespace('parallelDist')
   
   if(!is.matrix(DataOrDistances)){
     warning('DataOrDistances is not a matrix. Calling as.matrix()')
@@ -23,14 +25,16 @@ InspectDistances=function(DataOrDistances,method= "euclidean",sampleSize = 10000
   if (isSymmetric(DataOrDistances)) {
     # nach Cls sortieren
     InputDistances = DataOrDistances
+    vecdist=InputDistances[upper.tri(InputDistances,F)]
   }
   else{
-    warning('Distances are not in a symmetric matrix, Datamatrix is assumed and dist() ist called')
-    InputDistances = as.matrix(dist(DataOrDistances, method = method, diag =TRUE))
+    print('Distances are not in a symmetric matrix, Datamatrix is assumed and dist() ist called')
+    #InputDistances = as.matrix(dist(DataOrDistances, method = method, diag =TRUE))
+    vecdist=as.vector(parallelDist::parDist(DataOrDistances,method = 'euclidean',diag = F,upper = F))
     #DataDists = DistanceMatrix(DataOrDistances, method = method)
   }
   
-  vecdist=InputDistances[upper.tri(InputDistances,F)]
+  
   # if(method!='euclidean')
   InspectVariable(vecdist,N = paste(method,'distance'),sampleSize=sampleSize,...)
   # else
